UriExtensions extension

Provides extended methods for Uri.

Uri用の拡張メソッドを提供します。

on

Methods

first({String separator = "/"}) String

Available on Uri, provided by the UriExtensions extension

Divides a Uri by separator and returns the first part.
last({String separator = "/"}) String

Available on Uri, provided by the UriExtensions extension

Divides a Uri by separator and returns the last part.
parentPath({String separator = "/"}) Uri

Available on Uri, provided by the UriExtensions extension

Uri is divided by separator and moved one level up.
splitLength({String separator = "/"}) int

Available on Uri, provided by the UriExtensions extension

Divides Uri by separator and returns the number of elements.
trimQuery() Uri

Available on Uri, provided by the UriExtensions extension

Trims Uri query characters (after ?).