ApiMultipartFile class
A file to be uploaded as part of a ApiMultipartFile.
This doesn't need to correspond to a physical file.
マルチパートリクエストの一部としてアップロードされるファイル。
物理ファイルに対応する必要はありません。
- Annotations
-
- @immutable
Constructors
-
ApiMultipartFile.fromBytes(String field, List<
int> value, {String? filename}) -
Creates a new ApiMultipartFile from a byte array.
factory
- ApiMultipartFile.fromPath(String field, String filePath, {String? filename})
-
Creates a new ApiMultipartFile from a path to a file on disk.
factory
- ApiMultipartFile.fromString(String field, String value, {String? filename})
-
Creates a new ApiMultipartFile from a string.
factory
Properties
-
bytes
→ List<
int> ? -
Binary data.
final
- field → String
-
Field name.
final
- filename → String?
-
File name.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → ApiMultipartFileType
-
The type of the multipart file.
final
- value → String?
-
String data and text data.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override